Crate dice_command_parser[−][src]
This crate provides functionality for the basic parsing of dice roll commands e.g. d100, d6 + 5, 2d20 - 1.
Given some input it will produce a DiceRollWithOp struct which can be used to then calculate a result.
Modules
Provides access to the DiceRoll struct.
Provides access to the DiceRollWithOp struct.
Provides access to the ParserError struct.
Functions
Takes a string of dice input and returns a Result<DiceRoll, ParserError>