#[non_exhaustive]pub struct Error {
pub status_code: StatusCode,
pub body: ErrorBody,
}Available on crate feature
api only.Expand description
An error returned from a Matrix API endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status_code: StatusCodeThe http response’s status code.
body: ErrorBodyThe http response’s body.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn new(status_code: StatusCode, body: ErrorBody) -> Self
pub fn new(status_code: StatusCode, body: ErrorBody) -> Self
Constructs a new Error with the given status code and body.
This is equivalent to calling body.into_error(status_code).
Sourcepub fn error_kind(&self) -> Option<&ErrorKind>
pub fn error_kind(&self) -> Option<&ErrorKind>
If self is a server error in the errcode + error format expected
for client-server API endpoints, returns the error kind (errcode).