Crate retry_future
source · [−]Re-exports
Modules
Macros
Return early with RetryPolicy::Fail
Return early with RetryPolicy::Retry
Structs
Retry futures exponentially.
Infinite retry
Simple retry strategy that is retrying futures after Duration
A future which is trying to resolve inner future
until it exits successfully or return an error.
Enums
Return type of inner future
inside RetryFuture
Traits
Used in RetryFuture to spawn
a new future in case it did not resolve to
Ok(_)Configuration trait for RetryFuture.