Modules
- actors
- common
- delta
- encoded
- error
- event
- execution
- fingerprint
- interface
- key
- metric
- retention
- row
- sort
- testing
- util
- value
Macros
- define_
event - internal
- Macro to create an internal error with automatic source location capture
- internal_
err - Macro to create an internal error result with automatic source location capture
- internal_
error - Macro to create an internal error result with automatic source location capture
- key_
prefix - return_
internal_ error - Macro to return an internal error with automatic source location capture This combines return_error! and internal_error! for convenience