Crate ribir_gpu

Crate ribir_gpu 

Re-exports

pub use wgpu_impl::*;

Modules

error
wgpu_impl

Structs

ColorAttr
DrawPhaseLimits
Represents the sets of limits an GPU backend can provide in a single draw
FilterPrimitive
GPUBackend
GradientStopPrimitive
ImagePrimIndex
ImgPrimitive
LinearGradientPrimIndex
LinearGradientPrimitive
MaskLayer
The mask layer describes an alpha channel layer that is used in the fragment shader to sample the alpha channel and apply it to the color.
RadialGradientPrimIndex
RadialGradientPrimitive
SdfMaskData
TexturePrimIndex
TexturePrimitive

Enums

MaskKind

Traits

GPUBackendImpl
Trait to help implement a gpu backend.
Texture
Texture use to display.

Functions

add_full_texture_vertices
add_rect_vertices
vertices_coord