Crate cli_config

Crate cli_config 

Modules

error
Errors
fs
This module contains file utilities The following traits should be used to ease read/write operation in the fs.

Functions

init
Initialize the configuration file for the specified type.
locate_config
Get the location of the config file on windows

Type Aliases

Result