Xvc Core Library for common operations
Re-exports
pub use types::cachetype::CacheType;pub use types::hashalgorithm::HashAlgorithm;pub use types::xvcdigest::CollectionDigest;pub use types::xvcdigest::ContentDigest;pub use types::xvcdigest::MetadataDigest;pub use types::xvcdigest::XvcDigest;pub use types::diff::Diff;pub use types::diff::DiffStore;pub use types::diff::DiffStore2;pub use types::diff::DiffStore3;pub use types::diff::DiffStore4;pub use types::diff::DiffStore5;pub use types::diff::apply_diff;pub use types::diff::diff_store;pub use types::diff::update_with_actual;pub use types::xvcfiletype::XvcFileType;pub use types::xvcmetadata::XvcMetadata;pub use types::xvcpath::TextOrBinary;pub use types::xvcpath::XvcCachePath;pub use types::xvcpath::XvcPath;pub use types::xvcroot::XvcRoot;pub use error::Error;pub use error::Result;pub use util::file::all_paths_and_metadata;pub use util::file::dir_includes;pub use util::file::directory_paths;pub use util::file::glob_includes;pub use util::file::glob_paths;pub use util::file::XvcPathMetadataMap;Modules
Print command aliases to be sourced in shells.
xvc check ignore CLI handling module
Error messages for Xvc core crate
Get the Xvc root directory for the current project
Xvc basic types used across the whole program
Various utility functions
Constants
Channel size for crossbeam_channel::bounded used across the library.
TODO: This can be configurable for smaller/larger RAM sizes.
The initial content for
.xvc/.gitignore to hide files in .xvc/The Git directory for a project.
The standard ignore filename
Initial .xvgignore content when a project is initialized
The standard metadata directory
Functions
Creates a new project configuration by writing all default values.
This is used when initializing a new project.
The repository GUID is created here.