pub enum ErrorBody {
Standard(StandardErrorBody),
Json(Value),
NotJson {
bytes: Bytes,
deserialization_error: Arc<Error>,
},
}Available on crate feature
api only.Expand description
The body of a Matrix API endpoint error.
Variants
Standard(StandardErrorBody)
A JSON body with the fields expected for Matrix endpoints errors.
Json(Value)
A JSON body with an unexpected structure.
NotJson
A response body that is not valid JSON.
Implementations
Sourceimpl ErrorBody
impl ErrorBody
Sourcepub fn into_error(self, status_code: StatusCode) -> Error
pub fn into_error(self, status_code: StatusCode) -> Error
Convert the ErrorBody into an Error by adding the http status code.
This is equivalent to calling Error::new(status_code, self).