pub struct AlertDescription(pub u8);Expand description
The AlertDescription TLS protocol enum. Values in this enum are taken
from the various RFCs covering TLS, and are listed by IANA.
Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u8). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.
If a known value does not exist for a value you need, you can simply create it locally:
pub const MyValue: AlertDescription = AlertDescription(123);The Debug impl for this type also looks up and pretty-prints
known named items. Unknown values are formatted in hexadecimal.
Tuple Fields
0: u8Implementations
Sourceimpl AlertDescription
impl AlertDescription
pub const CloseNotify: Self
pub const UnexpectedMessage: Self
pub const BadRecordMac: Self
pub const DecryptionFailed: Self
pub const RecordOverflow: Self
pub const DecompressionFailure: Self
pub const HandshakeFailure: Self
pub const NoCertificate: Self
pub const BadCertificate: Self
pub const UnsupportedCertificate: Self
pub const CertificateRevoked: Self
pub const CertificateExpired: Self
pub const CertificateUnknown: Self
pub const IllegalParameter: Self
pub const UnknownCa: Self
pub const AccessDenied: Self
pub const DecodeError: Self
pub const DecryptError: Self
pub const ExportRestriction: Self
pub const ProtocolVersion: Self
pub const InsufficientSecurity: Self
pub const InternalError: Self
pub const InappropriateFallback: Self
pub const UserCanceled: Self
pub const NoRenegotiation: Self
pub const MissingExtension: Self
pub const UnsupportedExtension: Self
pub const CertificateUnobtainable: Self
pub const UnrecognizedName: Self
pub const BadCertificateStatusResponse: Self
pub const BadCertificateHashValue: Self
pub const UnknownPskIdentity: Self
pub const CertificateRequired: Self
pub const NoApplicationProtocol: Self
pub const EncryptedClientHelloRequired: Self