#[non_exhaustive]pub struct UserLimitExceededErrorData {
pub info_uri: String,
pub can_upgrade: bool,
}Available on crate feature
api only.Expand description
Data for the M_USER_LIMIT_EXCEEDED ErrorKind.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.info_uri: StringA URI that the client can present to the user to provide more context on the encountered limit and, if applicable, guidance on how to increase the limit.
The homeserver MAY return different values depending on the type of limit reached.
can_upgrade: boolWhether the specific limit encountered can be increased.
If true, it indicates that the specific limit encountered can be increased, for example
by upgrading the user’s account tier. If false, the limit is a hard limit that cannot be
increased.
Defaults to false.
Implementations